@@ -5,7 +5,7 @@ use Carp;
 use JSON;
 use Search::Tools::XML;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002001';
 
 sub new {
     my $class       = shift;
@@ -195,7 +195,14 @@ Dezi::Server::About - Dezi server introspection metadata
 Dezi::Server::About allows a Dezi::Server to introspect,
 and returns an object describing the server.
 
-This class is used internally Dezi::Server.
+The About response is what you get, in JSON format, when you issue
+a GET request to the Dezi root path. It allows
+client applications to find out details about
+the server, including what methods are available
+and which URI paths should be used for searching
+and indexing.
+
+This class is used internally by Dezi::Server.
 
 =head1 METHODS
 
@@ -221,7 +228,7 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Dezi::About
+    perldoc Dezi::Server::About
 
 
 You can also look for information at:
